%****************************************************************************
%  Name     : Flory
%  Function : Computes the volume fraction of polymer in the polymer phase
%  Method   : Solves the Flory Huggins equation for PVC
%			  Ref: Kiparissides et al., 1997, Ind.Eng. Chem. Res., 36,1253-1267.
%  Author   : Peter Singstad	2004-03-21
%  Rewritten: Peter Singstad	2005-03-03
%  Modified:  Peter Singstad    2008-01-13
%****************************************************************************/

function vf = Flory(Tr,am)

[c4, c3, c2, c1, c0 ] = coeffFlory(Tr,am);

x = 1.0 - 0.25 .* am * am * am .* ( 1.0 + (Tr-323.15) ./ 500 );

for i=1:4,
   r = log(1-x) + (((c4 .* x + c3) .* x + c2 ) .* x + c1 ) .* x + c0;
   dr = 1./(x-1) + (( 4*c4 .* x + 3*c3) .* x + 2*c2 ) .* x + c1;
   
   x = x - r ./ dr;
end

vf = x;
