%****************************************************************************
%  Name     : CoeffFlory
%  Function : Returns parameters for Flory-Huggins equation for PVC. This
%  is used to find the interaction parameter and the polymer volume
%  fraction in the polymer rich phase. 
%  Method   : Ref: Kiparissides et al., 1997, Ind.Eng. Chem. Res. Page 1266
%  Author   : Peter Singstad and Anette H. Helgesen
%****************************************************************************/

function [c4, c3, c2, c1, c0] = coeffFlory(Tr,am)

	Xs	= 0.26*1;				
	a	= 0.15524*1;				
	b	= 0.35311*1;				
	c	= -0.50527*1;				
	d	= 11.3605*1;				
	e	= 199.96*1;				%This is from V1*(d1-d2)^2/R [K]
	f	= 6244.49*1;				%This is from 2*d1*d2/R [K]
	
   c4 = f * b / Tr;
   c3 = f * c / Tr;
   c2 = Xs + e/Tr + f*a/Tr + f*d/(Tr*Tr);
   c1 = 1.0;
   c0 = - log( am );
