%******************************************************************************
%  Name     : density_process
%  Function : Calculate density of water, monomer and PVC as a function of temperature
%  Referance: Kiparissides (1997)
%  Author   : Anette H. Helgesen 2011
%*****************************************************************************/

function [rho_m,rho_w,rho_p] = density_process(Tr)
%				 Out: Sat. pressure for VCM [Pa]	
%	             In:  Temperature			[K]
rho_m=947.1-(1.746*(Tr-273.15))-((3.24*10^-3)*(Tr-273.15)^2); %Density of monomer [g/l] (Constant value 911)
rho_p=(10^3)*exp(0.4296-(3.274*10^-4)*Tr);                    %Density of polymer [g/l] (Constant value 1392)
rho_w=1011-(0.4484*(Tr-273.15));                              %Density of water [g/l] (Constant value 1000)