function par =emulsion_parameters()
% ********** Constants and parameters for model ***********
%In the files given, the values of the parameters are not actual, and they should not be associated with the case.
%OTHER PARAMETERS
par.Vr=10000;                 %Reactor volume [l]
par.Buffer=1000;              %Buffer put into reactor [g] (can be modelled as water)
par.f_1=0.700;                %Effeiciency factor for initiator
par.Na=6.022*10^23;           %Avogadros constant [molecules/mol]
par.R=8.314;                  %Gas constant [J/mol K]
par.xc=0.77;                  %Critical conversion, found from process data
%HEAT CAPACITY
par.cp_polymer0=0.934;        %Heat capasity of reactor content [J/g K]
par.cpm0=0.9504;              %Heat capasity monomer [J/g K]
par.cpw0=4.187;               %Heat capacity of water [J/g K]
par.cp_emu=0;                 %Heat capacity of emulsifier in start
par.cpi0=0;                   %Heat capacity of initator 
par.cp_met=0.460;             %Heat capacity of steel [J/g,K]

%MOLECULAR WEIGHT
par.MWm=62.498;               %Molecular weight of monomer [g/mol]
par.MWI=1;                    %Molecular weight of initiator [g/mol]
par.MWw=18;                   %Molecular weight of water [g/mol]
par.MWemu=1;                  %Molecular w of emulgator [g/mol], from Ineos
par.Nmin=100204;              %Moles of monomer feed into the reactor
%DENSITY
par.rho_i=1;                  %Density of initiator [g/l]
par.rho_emu=1;                %Density of emulgator [g/l]


%FEED DATA
par.m_em1_tot=1000;           %Emulgator nr 1 into reactor+water that the emulgator is dissolved in [g]
par.c_em1=1;                  %Concentration emulgator 1 [%]
par.c_em2=1;                  %Concentration emulgator 2 [%]
par.Ta=300;                   %Temperature outside of the reactor, ambient temperature 
par.Fm_in=100204;             %Inlet of monomer into reactor [mol]
par.m_w=1000000;              %Mass of water into reactor +buffer. [g]
par.m_m=1000000;              %Monomer put into the reactor [g]
par.m_i=1000;                 %Initiator into the reactor [g]
        
%HEAT TRANSFER COEFFICIENTS AND AREA
par.deltaHp=97*10^3;         %Reaction entalpy for polymerization [J/mol]
par.Ut=25;                   %Top of reactor  [W/m2,K]
par.Ua=25;                   %heat transfer coefficient to the reactor environment [W/m2,K]
par.Ai=10;                   %Heat transfer area, jacket and reactor [m2]
par.A_t=10;                  %Reactor top heat transfer area [m2]
par.Aa=10;                   %Environmental heat transfer area, from jacket to environment [m2]
par.m_met=10000000;          %Mass of steel [g]


%% ACTIVATION ENERGY, found in literature for each process. 
par.Ep=60000; par.Et=4200;  par.Ei=1;                       %[J/mol] 
par.Ap=3.3*10^6; par.At=1.3*10^12;
par.kp0=52725; par.kt0=21*10^8; par.ki0=1;
par.Tref_I=343.15; par.Tref_p=323; par.Tref_t=333.15;     

end
