%*************************************************************************
%  Name     : estimation_U
%  Function : Model used to estimate U
%  Method   : Estimate U with lsqcruvefit, have to run the model
%  Author   : Anette H. Helgesen 2011
%*************************************************************************
function F =estimation_U(t,x,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi,a0,a1,a2)
%% Data used in model
index=floor(t/10)+1;
if index+1 < length(Tjin)
dt=(t-10*index)/10;
Tjin=dt*Tjin(index+1)+(1-dt)*Tjin(index);

else Tjin=Tjin(end);
end

index=floor(t/10)+1;
if index+1 < length(Tr)
dt=(t-10*index)/10;
Tr=dt*Tr(index+1)+(1-dt)*Tr(index);

else Tr=Tr(end);
end

index=floor(t/10)+1;
if index+1 < length(Xi)
dt=(t-10*index)/10;
Xi=dt*Xi(index+1)+(1-dt)*Xi(index);

else Xi=Xi(end);
end

% Water flow in cooling jacket.
Wc=((2.273*10^-13)*t^4)-((1.153*10^-8)*t^3)+((0.0001704)*t^2)-(0.6442*t)+6*10^4;
%% Part  II. Extract present value of states
Tjout=x(1);                    %Reactor jacket out temperature [K]
%% Part III. Intermediate calculations 
mj=100000;                     %Water in cooling jacket, given from Ineos [g] 
cpw=4.02*exp((1.99*10^-4)*Tr); %Heat capacity of water   [J/g,K]
Tave=(Tjout+Tjin)/2;           %Average temperature in cooling jacket
U=a0+a1*Xi+a2*Xi^2;
%% Part III. Evaluate ODE set
dx1=(((Wc*cpw*(Tjin-Tjout))+(par.Ua*par.Aa*(par.Ta-Tjout))+(U*par.Ai*(Tr-Tave)))/((mj*cpw)+(par.m_met*par.cp_met)));
F=dx1;

end


