%****************************************************************************
%  Name     : InvFloryPVC
%  Function : Computes the activity coefficient for VCM solved in PVC
%  Method   : Solves the Flory Huggins equation for PVC
%  			  Ref: Kiparissides et al., 1997, Ind.Eng. Chem. Res., 36,1253-1267.
%  Author   : Peter Singstad	2008-01-13
%****************************************************************************/

function am = invFlory(Tr,vf)

[c4, c3, c2, c1, c0 ] = coeffFlory(Tr, 1.0);

if ( vf >= 1.0 ),
   am = 0.0;
   return;
elseif ( vf <= 0.0 ),
   am = 1.0;
   return;   
end

c0 = log(1-vf) + (((c4 .* vf + c3) .* vf + c2 ) .* vf + c1 ) .* vf;

am = exp( c0 );
