%**************************************************************************
%  Name     : main_model
%  Function : Solve the ODEs, and simulate the whole batch
%  Author   : Anette H. Helgesen 2011
%**************************************************************************
clear all
clc
load 2oct10
par = emulsion_parameters();
%% Timespan and states
t_end=31620; 
tspan1=[0:10:4840]; 
tspan2=[4850:10:18700];
tspan3=[18710:10:t_end];
times=[];
States=[];
%% Initial values for the states.
x10=[14.4617 1e-10 139204 1e-10 359 8.8176]; 
options=odeset('BDF','on','AbsTol',1e-06,'RelTol',1e-06); %,'maxStep',0.0001
format short G
Nm_in=139204
Tr=data((359:3521),7)+273.15;
Tjin=data((359:3521),5)+273.15;
Xi=data((359:3521),2)/100;

%% ODE solver
%After dosing of emulgator, but not in this interval of the batch time
Emu=0; Ve2=0; m_em2_tot=0; Win=0; cin=0; Tin=0; 
tic
[T,x1]= ode15s(@model,tspan1,x10,options,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi);

times=[times;T];
States=[States;x1];
% Start next interval of batch with putting more surfactant into reactor.
x20 = x1(end,:)';  
Emu=0.03; Ve2=500; m_em2_tot=50000; Win=0.05; cin=4; Tin=300;  
[TT,x2]=ode15s(@model,tspan2,x20,options,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi);
times=[times;TT];
States=[States;x2];

x30 = x2(end,:)';  
Emu=0; Ve2=0; m_em2_tot=0; Win=0; cin=0; Tin=0;  
[TTT,x3]=ode15s(@model,tspan3,x30,options,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi);
times=[times;TTT];
States=[States;x3];

nstep=length(times);
N_bar=zeros(size(times));
X=zeros(size(times));
N_polymer=zeros(size(times));
Rp=zeros(size(times));
Mp=zeros(size(times));

%Parameters and intermediate calculations in function
for i=1:nstep
    State=States(i,:);
    [F N_bar(i) X(i) N_polymer(i) Rp(i) Mp(i)] = model(times(i),State,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi);
   
end
toc
