%****************************************************************************
%  Name     : main_model_radicals_ode
%  Method   : Solves model with using ODE15s
%  Author   : Anette Hoel Helgesen 2011
%****************************************************************************/
warning 'off'
clear all
clc
%Load data from Ineos
load 2oct10
par = emulsion_parameters();
%% Timespan and states
t_end=31620; 
tspan1=[0:10:4840]; 
tspan2=[4850:10:18700];
tspan3=[18710:10:t_end];
times=[];
States=[];
%% Initial values for the states.
x10=[14.4617 139200 359 8.8176 0.0019 1e-04 1e-20 1e-20 1e-20]; 

options=odeset('BDF','on','AbsTol',1e-06,'RelTol',1e-06); %,'maxStep',0.0001
format('shortG')
Nm_in=139200;
Tr=data((359:3521),7)+273.15;
Tjin=data((359:3521),5)+273.15;
Tjout=data((359:3521),6)+273.15;
Xi=data((359:3521),2)/100;

%% ODE solver
%After dosing of emulgator, but not in this interval of the batch time

Emu=0; Ve2=0; m_em2_tot=0; Win=0; cin=0; Tin=0; 
tic
[T,x1]= ode15s(@model_radicals_states,tspan1,x10,options,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi);

times=[times;T];
States=[States;x1];
% Start next interval of batch with putting more emulgator into reactor.
x20 = x1(end,:)';  
Emu=0.01; Ve2=500; m_em2_tot=500000; Win=0.02; cin=4.187; Tin=300;  
[TT,x2]=ode15s(@model_radicals_states,tspan2,x20,options,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi);
times=[times;TT];
States=[States;x2];

x30 = x2(end,:)';  
Emu=0; Ve2=0; m_em2_tot=0; Win=0; cin=0; Tin=0;  
[TTT,x3]=ode15s(@model_radicals_states,tspan3,x30,options,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi);
times=[times;TTT];
States=[States;x3];


nstep=length(times);
n_bar=zeros(size(times));
X=zeros(size(times));
N_polymer=zeros(size(times));
Rp=zeros(size(times));
Mp=zeros(size(times));
Vp=zeros(size(times));
kp=zeros(size(times));
kt=zeros(size(times));
Np=zeros(size(times));
toc

%Parameters and intermediate calculations in function
for i=1:nstep
    State=States(i,:);
    [F n_bar(i) X(i) N_polymer(i) Rp(i) Mp(i) Np(i)] = model_radicals_states(times(i),State,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi);
   
end

%% Figures
%Change the units
timeh=times./3600;
t_end=t_end/3600;

figure(1)
set(gcf,'Color',[1,1,1])
subplot(2,1,1)
plot(timeh,States(:,1),'Linewidth',2)
title('Initiator in reactor','FontSize',12,'FontWeight','bold','FontName','Times');
xlabel('Time [h]','FontSize',12,'FontName','Times')
ylabel('Initiator [mol]','FontSize',12,'FontName','Times')
xlim([0 t_end])
grid on

subplot(2,1,2)
plot(timeh,States(:,2),'Linewidth',2)
hold on
plot(timeh,(1-data((359:3521),2)/100)*Nm_in,'r','Linewidth',2)
title('Unreacted monomer','FontSize',12,'FontWeight','bold','FontName','Times');
xlabel('Time [h]','FontSize',12,'FontName','Times')
ylabel('Monomer [mol]','FontSize',12,'FontName','Times')
legend('Model','Data:Ineos','Location','NorthEast')
xlim([0 t_end])
grid on

figure(2)
plot(timeh,States(:,3),'Linewidth',2)
hold on
plot(timeh,data((359:3521),6)+273.15,'r')
title('Cooling temperature outlet','FontSize',12,'FontWeight','bold','FontName','Times');
xlabel('Time [h]','FontSize',12,'FontName','Times')
ylabel('Temperature [K]','FontSize',12,'FontName','Times')
legend('Model','Data:Ineos','Location','NorthEast')
xlim([0 t_end])
grid on

% 
figure(3)
set(gcf,'Color',[1,1,1])
subplot(2,1,1)
plot(timeh,n_bar,'Linewidth',2)
title('Average number of radicals per particle','FontSize',12,'FontWeight','bold','FontName','Times');
xlabel('Time [h]','FontSize',12,'FontName','Times')
ylabel('Radicals [number]','FontSize',12,'FontName','Times')
xlim([0 t_end])
ylim([0 0.1])
grid on

subplot(2,1,2)
plot(timeh,X,'Linewidth',2)
hold on
plot(timeh,data((359:3521),2)/100,'r','Linewidth',1)
title('Conversion of monomer','FontSize',12,'FontWeight','bold','FontName','Times');
xlabel('Time [h]','FontSize',12,'FontName','Times')
ylabel('Conversion [-]','FontSize',12,'FontName','Times')
legend('Model','Data:Ineos','Location','SouthEast')
xlim([0 t_end])
grid on


figure(4)
subplot(2,1,1)
plot(timeh,N_polymer,'Linewidth',2)
title('Polymer in reactor','FontSize',12,'FontWeight','bold','FontName','Times');
xlabel('Time [h]','FontSize',12,'FontName','Times')
ylabel('Polymer particles [mol]','FontSize',12,'FontName','Times')
xlim([0 t_end])
grid on

subplot(2,1,2)
plot(timeh,Mp,'Linewidth',2)
title('Amount of monomer in polymer particle','FontSize',12,'FontWeight','bold','FontName','Times');
xlabel('Time [h]','FontSize',12,'FontName','Times')
ylabel('Monomer concentration [mol/l]','FontSize',12,'FontName','Times')
xlim([0 t_end])
ylim([0 10])
grid on

