%In the files given, the values of the parameters are not actual, and they should not be associated with the case.
function [F N_bar X N_polymer Rp Mp Pm_sat P] = model_nov(t,x,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi)
%% Process data from Ineos. Data made to polynomials.
index=floor(t/10)+1;
if index+1 < length(Tjin)
dt=(t-10*index)/10;
Tjin=dt*Tjin(index+1)+(1-dt)*Tjin(index);

else Tjin=Tjin(end);
end

index=floor(t/10)+1;
if index+1 < length(Tr)
dt=(t-10*index)/10;
Tr=dt*Tr(index+1)+(1-dt)*Tr(index);

else Tr=Tr(end);
end

index=floor(t/10)+1;
if index+1 < length(Xi)
dt=(t-10*index)/10;
Xi=dt*Xi(index+1)+(1-dt)*Xi(index);

else Xi=Xi(end);
end

%% Part  II. Extract present value of states
Nini=x(1);                 %Initiator left in reactor [mol]
Np=x(2);                   %Number of particles [mol]
Nm=x(3);                   %Monomer left in reactor [mol]
Nrad=x(4);                 %Radicals in reactor [mol]
Tjout=x(5);                %Reactor jacket out temperature [K]
S=x(6);


%% Rate constants
[kp,ki,kt,ka,k_tr_mon,k_tr_CTA,k_tr_pol,kzp,kz_aq,Zp,Zaq]=rate_constant(par,Tr);

%% Part III. Intermediate calculations 
Wc=((2.273*10^-13)*t^4)-((1.153*10^-8)*t^3)+((0.0001704)*t^2)-(0.6442*t)+6*10^4;  %Flow rate of water inside the jacket [g/s]
mj=1000000;                                         %Water in cooling jacket [g]

%Density, change with temperature in reactor (Kiparissides 1997). 
[rho_m,rho_w,rho_p]=density_process(Tr);
%Virial coefficients, from Kiparissides,w=water and m=monomer
[Bm,Bw,Bwm]=virial_coeff(Tr,par);
d_mw=2*Bwm-Bm-Bw;

%Emulgator into the reactor, find concentration of the emulgator
m_em2=par.c_em2*m_em2_tot;                                    %Total amount of only emulgator
m_em1=par.c_em1*par.m_em1_tot;                                %Total amount of only emulgator [g]
n_em1=(m_em1/par.MWemu);                                      %Mol of emulgator
Ve1=par.m_em1_tot/rho_w;                                      %Emulgator feed into reactor, model it as water [liter]
Vw=par.m_w/(rho_w)+Ve1+Ve2+(par.Buffer/rho_w);                %Volume of water in reactor [liter], surfactant used as water
m_w=par.m_w+m_em2_tot;                                        %Mass of water in reactor(Surfactant+buffer i model as water)

Vm0=(par.m_m)/rho_m;                                          %Initial volume of monomer in reactor [liter]
Vi=par.m_i/par.rho_i;                                         %Initiator volume, per liter water
Vw=par.m_w/(rho_w)+Ve1+Ve2+(par.Buffer/rho_w);                %Volume of water in reactor [liter], surfactant used as water
as=1;                                                         %m2/mole
                                              

%Heat capacity (Kiparissides (1997))
cpm=(4.178*(18.67+(0.0758*(Tr-273.15))))/62.5;                %Heat capacity of monomer [J/g,K]
cpw=4.02*exp((1.99*10^-4)*Tr);                                %Heat capacity of water   [J/g,K]
cp_polymer=par.cp_polymer0; 
m_m=par.MWm*Nm; m_p=par.m_m-(par.MWm*Nm);                     %Mass of monomer and polymer in reactor [g]
mcp=(m_m*cpm)+((par.m_w+par.m_i+par.m_em1_tot+m_em2_tot)*cpw)+(m_p*cp_polymer); %Specifict heat capacity of reactor mixture [J/K]

%Mol of polymer particles, conversion and volume of reactor mixture
Mm=Nm*par.MWm;                                                %Mass of monomer left in reactor [g]
N_polymer=par.Fm_in-Nm;                                       %Polymer in reactor [mol]
m_polymer=par.m_m-Mm;
X=(1-(Nm/par.Fm_in));                                         %Conversion
CTA=0;                                                        %Chain transfer agaent [mol/l]
frac_p=(m_polymer*rho_p)/(m_polymer*rho_p+rho_m*Mm);
[Pm_sat,Pw_sat] =saturation_pressure(Tr);
Psat=Pm_sat+Pw_sat;

if X >= 0 && X <= 0.005
    kde=800;
elseif X > 0.005 && X <= 1
    kde=((5.189*10^4)*X^5)-((1.513*10^5)*X^4)+((1.553*10^5)*X^3)-((6.02*10^4)*X^2)+(1352*X)+3030;
 else
    kde=0;
end

%% Monomer in polymer rich phase
[Mp,Vp,P]=monomer_concentration_particle(par,rho_m,rho_p,X,Psat,Xi);

%% Average number of radicals per particle
r_p=(202*10^-9)/2;       %Radius of a particle, assumed monodisperse
vp = Vp / Np / par.Na;

a_Solvent = as * S;
a_Particles = (4*pi*Np*par.Na)^(1/3) * (0.003*Vp)^(2/3);
a_Miscelles = max( (a_Solvent-a_Particles), 0.0 );
ratefactor = a_Miscelles / a_Solvent;


jmax=5;                                                     %Jmax can be defined her

Nrw=( 2*ki*par.f_1*Nini*(1-ratefactor) + kde*Nrad )/((ka*Np*par.Na)+kde-(kz_aq*Zaq)); 

[para mat]=radicals_matrix_Peter(jmax,par,ka,kde,Nrw,Np,kt,kzp,Zp,vp, 2*par.f_1*ki*Nini*ratefactor); 

Nrad_parti=Nrad-Nrw;
N_bar=Nrad_parti/Np;

% Polymerization rate
Rp=kp*Mp*Nrad_parti;                                        %(Nrad-Nrw): Radicals in particles.
Tave=(Tjout+Tjin)/2;                                        %Average temperature in cooling jacket

%Possible to calculate U, to see how it change
a0=5.166542937519126e+02;
a1=-5.383589032168123e+02;
a2=4.257394824341245e+02;
U=a0+a1*Xi+a2*Xi^2;

%% Part III. Evaluate ODE set
d_Nini = -ki*Nini;
d_Np   = 2 * par.f_1 * ki * Nini * ratefactor;
d_Nm   = -(Rp);
d_Nrad = 2*par.f_1*ki*Nini - kt/(vp*par.Na)*para - Nrad*(kzp*Zp-kz_aq*Zaq);
d_Tjout= (((Wc*cpw*(Tjin-Tjout))+(par.Ua*par.Aa*(par.Ta-Tjout))+(U*par.Ai*(Tr-Tave)))/((mj*cpw)+(par.m_met*par.cp_met)));
d_S    = Emu;

F=[d_Nini; d_Np; d_Nm; d_Nrad; d_Tjout; d_S];


end


