%****************************************************************************
%  Name     : model_zero_one_system
%  Function : Assume all particles have zero or one radical.
%  Method   : Simple method derived in this work.
%  Author   : Anette Hoel Helgesen 2011
%****************************************************************************/
%In the files given, the values of the parameters are not actual, and they should not be associated with the case.
function [F X N1 N0] = model_zero_one_system(t,x,par,Emu,Ve2,m_em2_tot,Win,cin,Tin,Tjin,Tr,Xi)
%% Process data from Ineos. Data made to polynomials.
index=floor(t/10)+1;
if index+1 < length(Tjin)
dt=(t-10*index)/10;
Tjin=dt*Tjin(index+1)+(1-dt)*Tjin(index);

else Tjin=Tjin(end);
end

index=floor(t/10)+1;
if index+1 < length(Tr)
dt=(t-10*index)/10;
Tr=dt*Tr(index+1)+(1-dt)*Tr(index);

else Tr=Tr(end);
end

index=floor(t/10)+1;
if index+1 < length(Xi)
dt=(t-10*index)/10;
Xi=dt*Xi(index+1)+(1-dt)*Xi(index);

else Xi=Xi(end);
end

%% Part  II. Extract present value of states
Nini=x(1);                 %Initiator left in reactor [mol]
Np=x(2);                   %Number of particles [mol]
Nm=x(3);                   %Monomer left in reactor [mol]
Tjout=x(4);                %Reactor jacket out temperature [K]
S=x(5);
%% CONSTANTS that are unknown, have to be/should be estimated
[kp,ki,kt,ka,k_tr_mon,k_tr_CTA,k_tr_pol,kzp,kz_aq,Zp,Zaq]=rate_constant(par,Tr);

%% Part III. Intermediate calculations 
Wc=((2.273*10^-13)*t^4)-((1.153*10^-8)*t^3)+((0.0001704)*t^2)-(0.6442*t)+6*10^4;  %Flow rate of water inside the jacket [g/s]
mj=1000000;                          %Water in cooling jacket, given from Ineos [g] 

%Density, change with temperature in reactor (Kiparissides 1997). 
[rho_m,rho_w,rho_p]=density_process(Tr);
%Virial coefficients, from Kiparissides,w=water and m=monomer
[Bm,Bw,Bwm]=virial_coeff(Tr,par);
d_mw=2*Bwm-Bm-Bw;

%Emulgator into the reactor, find concentration of the emulgator
m_em2=par.c_em2*m_em2_tot;                                    %Total amount of only emulgator
m_em1=par.c_em1*par.m_em1_tot;                                %Total amount of only emulgator [g]
n_em1=(m_em1/par.MWemu);                                      %Mol of emulgator
Ve1=par.m_em1_tot/rho_w;                                      %Emulgator feed into reactor, model it as water (emulgator+water=water) [liter]
Vw=par.m_w/(rho_w)+Ve1+Ve2+(par.Buffer/rho_w);                %Volume of water in reactor [liter], surfactant used as water
Vm0=(par.m_m)/rho_m;                                          %Initial volume of monomer in reactor [liter]
Vi=par.m_i/par.rho_i;                                         %Initiator volume, per liter water
Vw=par.m_w/(rho_w)+Ve1+Ve2+(par.Buffer/rho_w);                %Volume of water in reactor [liter], surfactant used as water
as=1;                                                         %as m2/mol
m_w=par.m_w+m_em2_tot;                                        %Mass of water in reactor(Surfactant+buffer i model as water)
                                               

% Heat capacity (Kiparissides (1997))
cpm=(4.178*(18.67+(0.0758*(Tr-273.15))))/62.5;                %Heat capacity of monomer [J/g,K]
cpw=4.02*exp((1.99*10^-4)*Tr);                                %Heat capacity of water   [J/g,K]
cp_polymer=par.cp_polymer0; 
m_m=par.MWm*Nm; m_p=par.m_m-(par.MWm*Nm);                    %Mass of monomer and polymer in reactor [g]
mcp=(m_m*cpm)+((par.m_w+par.m_i+par.m_em1_tot+m_em2_tot)*cpw)+(m_p*cp_polymer); %Specifict heat capacity of reactor mixture [J/K]

%Mol of polymer particles, conversion and volume of reactor mixture
Mm=Nm*par.MWm;                                               %Mass of monomer left in reactor [g]
N_polymer=par.Fm_in-Nm;                                       %Polymer in reactor [mol]
m_polymer=par.m_m-Mm;
X=(1-(Nm/par.Fm_in));                                         %Conversion
CTA=0;                                                        %Chain transfer agaent [mol/l]
frac_p=(m_polymer*rho_p)/(m_polymer*rho_p+rho_m*Mm);

[Pm_sat,Pw_sat] =saturation_pressure(Tr);
Psat=Pm_sat+Pw_sat;
%% Monomer in polymer rich phase
[Mp,Vp]=monomer_concentration_particle(par,rho_m,rho_p,X,Psat,Xi);

%% Monomer distribution in four phases (Flory-Huggins is used)
K1=0.0088;
%[Mp,Vp,Mm_m,M_w,Mg,Mp_m,P]=monomer_concentration_4phase(Nm,Tr,par,Pm_sat,Pw_sat,Bm,Bw,Bwm,rho_p,rho_w,rho_m,X,K1,m_polymer,Mm,d_mw,m_w);

%% Average number of radicals per particle
r_p=(200*10^-9)/2; %Radius of a particle, assumed monodisperse (given from Ineos)

kde=100;
vp = Vp / Np / par.Na;

a_Solvent = as * S;
a_Particles = (4*pi*Np*par.Na)^(1/3) * (0.003*Vp)^(2/3);
a_Miscelles = max( (a_Solvent-a_Particles), 0.0 );
ratefactor = a_Miscelles / a_Solvent;

N1=quadratic_equation(par,ki,Nini,ka,Np,kde,kt,vp);

Nrw=(par.f_1*ki*Nini)/(ka*par.Na*N1);

% Polymerization rate
Rp=(kp*Mp*N_bar*Np);                                       
Tave=(Tjout+Tjin)/2;  %Average temperature in cooling jacket

%Possible to calculate U, to see how it change
a0=5.166542937519126e+02;
a1=-5.383589032168123e+02;
a2=4.257394824341245e+02;

U=a0+a1*Xi+a2*Xi^2;
%% Part III. Evaluate ODE set
d_Nini = -ki*Nini;
d_Np   = 2 * par.f_1 * ki * Nini * ratefactor;
d_Nm   = -(Rp);
d_Tjout= (((Wc*cpw*(Tjin-Tjout))+(par.Ua*par.Aa*(par.Ta-Tjout))+(U*par.Ai*(Tr-Tave)))/((mj*cpw)+(par.m_met*par.cp_met)));
d_S    = Emu;

F=[d_Nini; d_Np; d_Nm; d_Tjout; d_S];

end


