%************************************************************************
%  Name     : monomer_concentration_coeff
%  Function : Calculate monomer concentration in polymer rich phase, by
%  using partition coefficients. The calculations can be changed depending
%  on which partition coefficient that is found for the system
%  Ref      : Polymer Reaction Engineering, Jose Asua, 2007.      
%  Author   : Anette H. Helgesen 2011
%************************************************************************/
function [Mp,Vpol] = monomer_concentration_coeff(par,Nm,rho_m,Vw)
Kaq_p=2; %Partition coefficient of monomer between the water and the particles
sigma=1; %Saturation degree of the particles
Vm=par.MWm*Nm/rho_m; %Volume of monomer left in reactor

Mc=Nm/Vm; %Monomer concentration in reactor mixture, from MB. Nm/Vm

%%Equation that have to be solved
Kd_aq=sigma/Kaq_p;
Vm_aq=Vw/Kd_aq;
Vp=(Kaq_p*(Vm-Vm_aq)*Vw)/Vm_aq; %Overall volume of particles
Vmp=Vm-Vw;
Vpol=Vp-Vmp;
Vmd=(Mc*V*(par.MWm/rho_m))-Vm_aq-Vmp;

Mp=(Vmp*rho_m)/(Vp*par.MWm);
end
