%****************************************************************************
%  Name     : monomer_concentration_particle
%  Function : Calculate monomer concentration of monomer in particle, for
%             both interval II and III.
%  Method   : Derived in this masterthesis
%  Author   : Anette H. Helgesen
%****************************************************************************/

function [Mp,Vp,P,Am]=monomer_concentration_particle(par,rho_m,rho_p,X,Psat,Xi)

k=1000;
    delta=1/(1+exp(k*(X-par.xc)));
    
    phi_m1=(1-par.xc)/(1-par.xc+(par.xc*(rho_m/rho_p)));
    
    Mp1=(phi_m1)*(rho_m/par.MWm);
    Vp1=(par.Fm_in*par.MWm*(X+1e-10))*((1/rho_p)+((1/rho_m)*((1/par.xc)-1)));  %[dm3]
    am1=1;
    P1=am1*Psat;
    Am_1=1;
    
    phi_m2=(1-X)/(1-X+(X*(rho_m/rho_p)));
    Mp2=(phi_m2)*(rho_m/par.MWm);
    Vp2=(par.Fm_in*par.MWm)*((X/rho_p)+((1-X)/rho_m));
    am2=((1-X)/(1-par.xc))*(par.xc/X);
    P2=am2*Psat;
    Am_2=((1-Xi)/(1-par.xc))*(par.xc/Xi);
    
    
    Am=((delta)*Am_1)+((1-delta)*Am_2);
    P=((delta)*P1)+((1-delta)*P2);
    Mp=((delta)*Mp1)+((1-delta)*Mp2);
    Vp=((delta)*Vp1)+((1-delta)*Vp2);
        
end