%****************************************************************************
%  Name     : radicals_matrix
%  Function : Linear equation set from all balances N(j) are solved.
%  Number of moles of particles with zero, one, two, etc. radicals are
%  found. (In this matlab file, jmax=5 is actually jmax=4)
%  Method   : This method is found and derive in this masterthesis
%  Author   : Anette H. Helgesen 2011
%****************************************************************************/
function [para mat]=radicals_matrix(jmax,par,ka,kde,Nrw,Np,kt,kzp,Zp,vp,rp)
A=zeros(jmax,jmax);
%The first row, for j=0
A(1,1)=1; A(1,2)=1; A(1,3)=1; A(1,4:jmax)=1; 
%Second row, for j=1
A(2,1)=(ka*Nrw*par.Na); A(2,2)=-(ka*Nrw*par.Na)-((kzp*Zp)+kde); A(2,3)=2*((kzp*Zp)+kde); A(2,4)=6*(kt/(par.Na*vp)); A(2,5:jmax)=0; % ok

for i=3:jmax-2
    
    A(i,i-1)=(ka*Nrw*par.Na);
    A(i,i)=(-(ka*Nrw*par.Na))-((kt/(par.Na*vp))*(i-1)*(i-2))-(((kzp*Zp)+kde)*(i-1));
    A(i,i+1)=((kzp*Zp)+kde)*(i);
    A(i,i+2)=(kt/(par.Na*vp))*(i+1)*(i);
    
end
%for jmax-1
A(jmax-1,jmax-2)=(ka*Nrw*par.Na);
A(jmax-1,jmax-1)=-((ka*Nrw*par.Na))-((kt/(vp*par.Na))*(jmax-2)*(jmax-3))-(((kzp*Zp)+kde)*(jmax-2));
A(jmax-1,jmax)=-((ka*Nrw*par.Na))+(((kzp*Zp)+kde)*(jmax-1));

%for jmax
A(jmax,jmax-1)=(ka*Nrw*par.Na);
A(jmax,jmax)=(ka*Nrw*par.Na)-((kt/(par.Na*vp))*(jmax-1)*(jmax-2))-(((kzp*Zp)+kde)*(jmax-1));

%The b matrix
b=zeros(jmax,1); b(1) = Np; b(2)=rp;

%C matrix used for the termination term when finding number of radicals
IMAX=jmax-2;
IMIN=3;
c= zeros(1,IMAX-IMIN+1);
for i=IMIN:IMAX
c(i-IMIN+1)=i*(i+1);
end
c =2*[0 0 2 6 c];
mat=A\b;
para=c*(A\b);