%*************************************************************************
%  Name     : rate_constant
%  Function : Use Arrhenius equation to calculate propagation, termination
%  and initiation rate constant. A referance rate constant and temerature
%  is used. Other rate constants are also given 
%  Author   : Anette H. Helgesen 2011
%*************************************************************************/

function [kp,ki,kt,ka,k_tr_mon,k_tr_CTA,k_tr_pol,kzp,kz_aq,Zp,Zaq]=rate_constant(par,Tr)

kp=(par.kp0*exp((-par.Ep/par.R)*((1/Tr)-(1/par.Tref_p))));

kt=(2*kp^2)/(((6.08*10^-3)/60)*exp(-5740*((1/Tr)-(1/par.Tref_t)))); %Literature value

ki=par.ki0*exp((-par.Ei/par.R)*((1/Tr)-(1/par.Tref_I)));   

ka=830;                    %Absorption of radicals [1/s]

%Transfer reactions rate and inhibitator data
k_tr_mon=0;                %Transfer to monomer 
k_tr_CTA=0;                %Chain transfer agaent rate constant
k_tr_pol=0;                %Transfer to polymer
kzp=0;                     %Inhibitator rate constant in particle [l/mole,s]
kz_aq=0;                   %Inhibitator rate constant in water [l/mole,s]
Zp=0;                      %Concentration of inhibitator in particle [mole/l]
Zaq=0;                     %Concentration of inhibitator in water    [mole/l]

end