%*************************************************************************
%  Name     : virial_coeff
%  Function : Calculate virial coefficients. Values used are for PVC
%  production. 
%  Method   : Ref: Kiparissides et al., 1997, Ind.Eng. Chem. Res. Page 1266
%  Author   : Anette H. Helgesen 2011
%*************************************************************************/

function [Bm,Bw,Bwm] = virial_coeff(Tr,par)
w_w=0.3342; w_m=0.1048;        %[-]
Tc_w=647.5; Tc_m=432;          %[K]
Pc_w=220.5e05; Pc_m=56e05;     %[Pa]
Vc_w=56;    Vc_m=179;          %[cm3/mol]
Zc_w=0.233; Zc_m=0.283;        %[-]

Tr_w=Tr/Tc_w;                  %[K]
Tr_m=Tr/Tc_m;                  %[K]

Bm_0=0.083-(0.422/(Tr_m^(1.6))); 
Bm_1=0.139-(0.172/(Tr_m^(4.2)));

Bm=((par.R*1000*Tc_m)/Pc_m)*(Bm_0+w_m*Bm_1); %[m3/mol]

Bw_0=0.083-(0.422/(Tr_w^(1.6))); 
Bw_1=0.139-(0.172/(Tr_w^(4.2))); 

Bw=((par.R*1000*Tc_w)/Pc_w)*(Bw_0+w_w*Bw_1); %[m3/mol]

w_wm=(w_w+w_m)/2;
Tc_wm=((Tc_w*Tc_m)^(0.5));
Zc_wm=(Zc_w+Zc_m)/2;
Vc_wm=((((Vc_w^(1/3))+(Vc_m^(1/3)))^3)/2)/1000;
%Pc_wm=((Zc_wm*par.R*1000*Tc_wm)/(Vc_wm))
Pc_wm = 107.e5;

Tr_wm=Tr/Tc_wm;

Bwm_0=0.083-(0.422/(Tr_wm^(1.6)));
Bwm_1=0.139-(0.172/(Tr_wm^(4.2)));

Bwm=((par.R*Tc_wm)/Pc_wm)*(Bwm_0+w_wm*Bwm_1); %[m3/mol]
end

